**To generate a service access report**

The following ``generate-service-last-accessed-details`` example starts a background job to generate a report that lists the services accessed by IAM users and other entities with a custom policy named ``intern-boundary``. You can display the report after it is created by running the ``get-service-last-accessed-details`` command. ::

    aws iam generate-service-last-accessed-details \
        --arn arn:aws:iam::123456789012:policy/intern-boundary

Output::

  {
      "JobId": "2eb6c2b8-7b4c-3xmp-3c13-03b72c8cdfdc"
  }

The following ``generate-service-last-accessed-details`` example starts a background job to generate a report that lists the services accessed by IAM users and other entities with the AWS managed ``AdministratorAccess`` policy. You can display the report after it is created by running the ``get-service-last-accessed-details`` command.::

    aws iam generate-service-last-accessed-details \
        --arn arn:aws:iam::aws:policy/AdministratorAccess

Output::

    {
        "JobId": "78b6c2ba-d09e-6xmp-7039-ecde30b26916"
    }
